package similo;

import static org.junit.jupiter.api.Assertions.assertTrue;

import java.io.File;
import java.time.Duration;

import org.junit.jupiter.api.Test;
import org.openqa.selenium.By;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.chrome.ChromeDriver;
import org.openqa.selenium.support.ui.ExpectedConditions;
import org.openqa.selenium.support.ui.WebDriverWait;

class SimiloTest
{
	private static String url="http://mimicservice.com/traveler";
//	private static String url="file:C:/traveler/index.html";

	@Test
	void test1a()
	{
		// Create a Chrome driver and open the url
		System.setProperty("webdriver.chrome.driver", (new File("bin/drivers/chromedriver.exe")).getAbsolutePath());
		WebDriver webDriver=new ChromeDriver();
		webDriver.get(url);

		// Create the adaptive and self-healing multi-locator
		Similo similo=new Similo(webDriver, "locators");

		// Fill out and send the contacts form
		similo.click("Contact");
		assertTrue(similo.check("Get In Touch", "{visible_text} = Get In Touch"));
		similo.type("Your name", "Michel");
		similo.type("Your email address", "michel.nass@bth.se");
		similo.type("Your subject of this message", "Contact me");
		similo.type("Write us something", "Please contact me");
		similo.click("Send Message");
		assertTrue(similo.check("we will contact you shortly", "{visible_text} = we will contact you shortly"));
	
		webDriver.quit();
	}

	@Test
	void test1b()
	{
		System.setProperty("webdriver.chrome.driver", (new File("bin/drivers/chromedriver.exe")).getAbsolutePath());
		WebDriver webDriver=new ChromeDriver();
		webDriver.get(url);
		WebDriverWait wait = new WebDriverWait(webDriver, Duration.ofSeconds(30));
		wait.until(ExpectedConditions.urlContains(url));
		try {

		Thread.sleep(1000);
		WebElement element;
		element=wait.until(ExpectedConditions.visibilityOfElementLocated(By.linkText("Contact")));
		element.click();
		element=wait.until(ExpectedConditions.visibilityOfElementLocated(By.tagName("H1")));
		assertTrue(element.getText().contains("Get In Touch"));
		element=wait.until(ExpectedConditions.visibilityOfElementLocated(By.id("name")));
		element.sendKeys("Michel");
		element=wait.until(ExpectedConditions.visibilityOfElementLocated(By.id("email")));
		element.sendKeys("michel.nass@bth.se");
		element=wait.until(ExpectedConditions.visibilityOfElementLocated(By.id("subject")));
		element.sendKeys("Contact me");
		element=wait.until(ExpectedConditions.visibilityOfElementLocated(By.linkText("Send Message")));
		element.click();
		element=wait.until(ExpectedConditions.visibilityOfElementLocated(By.tagName("H1")));
		assertTrue(element.getText().contains("we will contact you shortly"));

		} catch(Exception e) {}

		webDriver.quit();
	}
	
	@Test
	void test1c()
	{
		System.setProperty("webdriver.chrome.driver", (new File("bin/drivers/chromedriver.exe")).getAbsolutePath());
		WebDriver webDriver=new ChromeDriver();
		webDriver.get(url);
		sleep();
		webDriver.findElement(By.linkText("Contact")).click();
		sleep();
		String text=webDriver.findElement(By.tagName("H1")).getText();
		assertTrue(text.contains("Get In Touch"));
		sleep();
		webDriver.findElement(By.id("name")).sendKeys("Michel");
		webDriver.findElement(By.id("email")).sendKeys("michel.nass@bth.se");
		webDriver.findElement(By.id("subject")).sendKeys("Contact me");
		webDriver.findElement(By.linkText("Send Message")).click();
		sleep();
		text=webDriver.findElement(By.tagName("H1")).getText();
		assertTrue(text.contains("we will contact you shortly"));
		webDriver.quit();
	}

	@Test
	void test2()
	{
		System.setProperty("webdriver.chrome.driver", (new File("bin/drivers/chromedriver.exe")).getAbsolutePath());
		WebDriver webDriver=new ChromeDriver();
		webDriver.get("https://www.tesla.com/");

		Similo similo=new Similo(webDriver, "locators");
		similo.manageCookies("Tesla", webDriver);

		similo.click("Model Y");
		similo.click("Order Now");
		similo.click("English");
		similo.click("Model Y Performance");
		similo.click("Deep Blue Metallic");

		sleep(2000);
		webDriver.quit();
	}

	@Test
	void test3()
	{
		System.setProperty("webdriver.chrome.driver", (new File("bin/drivers/chromedriver.exe")).getAbsolutePath());
		WebDriver webDriver=new ChromeDriver();

		webDriver.get("https://arbetsformedlingen.se/");
		Similo similo=new Similo(webDriver, "locators");

		similo.click("Sök jobb i platsbanken");
		similo.enter("Sök på ett eller flera ord", "jobb");
		assertTrue(similo.check("Sortera efter relevans", "{visible_text} = Sortera efter relevans"));
		similo.click("Meny");
		similo.click("Start");
		similo.click("För arbetsgivare");
		assertTrue(similo.check("Välkommen arbetsgivare", "{visible_text} = Välkommen arbetsgivare"));

		webDriver.quit();
	}


	@Test
	void test4()
	{
		System.setProperty("webdriver.chrome.driver", (new File("bin/drivers/chromedriver.exe")).getAbsolutePath());
		WebDriver webDriver=new ChromeDriver();
	
		webDriver.get("https://www.skatteverket.se/");
		Similo similo=new Similo(webDriver, "locators_skatteverket");

		similo.click("Deklaration");
		similo.click("Så här deklarerar du");
		assertTrue(similo.check("På vilket sätt kan du deklarera", "{visible_text} = På vilket sätt kan du deklarera?"));
		similo.click("Du som ska göra ändringar, till exempel lämna en bilaga");
		similo.click("Dölj text");
		similo.click("Betala kvarskatt");
		assertTrue(similo.check("Du kan betala kvarskatten tidigare", "{visible_text} = Du kan betala kvarskatten tidigare"));
		similo.enter("Sök", "Kvarskatt");
		assertTrue(similo.check("Undvik kvarskatt", "{visible_text} = Undvik kvarskatt"));

		webDriver.quit();
	}

	void sleep()
	{
		sleep(2000);
	}
	
	void sleep(int milliseconds)
	{
		try
		{
			Thread.sleep(milliseconds);
		}
		catch (InterruptedException e)
		{
		}
	}
}
